fnss.topologies.parsers.parse_ashiip — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.topologies.parsers.parse_ashiip

`parse_ashiip`(file_name)

  Parse a topology from an output file generated by the aShiip topology generator

  Parameters : | path : str The path to the aShiip output file
  Returns : | topology : Topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »